@@ -4,6 +4,7 @@ import wsgi_intercept
 import shutil
 import os
 import sys
+import urllib
 
 from tiddlywebplugins.instancer.util import spawn
 import tiddlywebplugins.prettyerror.instance as instance_module
@@ -15,6 +16,8 @@ from tiddlywebplugins.prettyerror import init
 from wsgi_intercept import httplib2_intercept
 
 from tiddlyweb.store import Store
+from tiddlyweb.model.bag import Bag
+from tiddlyweb.model.tiddler import Tiddler
 
 def make_test_env():
     try:
@@ -52,3 +55,24 @@ def test_tiddlyweb_404():
     assert response['status'] == '404'
     assert response['content-type'] == 'text/html; charset=UTF-8'
     assert 'Path not found for "/bags/fake"' in content
+
+def test_404_with_unicode():
+    """
+    Apparently this bug is only tickled under some wsgi hosts, notably
+    apache with mod_wsgi.
+
+    So I thought, to test this some silliness would be require (below)
+    but that doesn't tickle the bug either.
+    """
+    title = urllib.unquote('test%C2%B7test').decode('utf-8')
+    store.put(Bag('test'))
+    store.put(Tiddler(title, 'test'))
+    response, content = http.request('http://0.0.0.0:8080/bags/test/tiddlers/test%C2%B7test')
+    assert response['status'] == '200'
+    response, content = http.request('http://0.0.0.0:8080/bags/test/tiddlers/test%C2%B7test/revisions/24')
+    assert response['status'] == '404', content
+
+    # here's the silly part
+    store.environ['silly.code'] = title
+    response, content = http.request('http://0.0.0.0:8080/bags/test/tiddlers/test%C2%B7test/revisions/24')
+    assert response['status'] == '404', content
